'use strict'

const { Adw, GLib, GObject, Gio, Gtk, Gdk } = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

var About = GObject.registerClass({
    GTypeName: 'AboutPrefs',
    Template: `file://${GLib.build_filenamev([Me.path, 'ui', 'about.ui'])}`,
    InternalChildren: [
        'app_icon_image',
        'app_name_label',
        'version_label',
    ]
}, class About extends Adw.PreferencesPage {
    constructor(window) {
        super({});

        this._app_icon_image.gicon = Gio.icon_new_for_string(`${Me.dir.get_child('icons').get_path()}/threshold-active.svg`);
        this._app_name_label.label = Me.metadata.name;
        this._version_label.label = Me.metadata.version.toString();

        // setup menu actions
        const actionGroup = new Gio.SimpleActionGroup();
        window.insert_action_group('prefs', actionGroup);

        // a list of actions with their associated link
        const actions = [
            {
                name: 'open-bug-report',
                link: 'https://gitlab.com/marcosdalvarez/thinkpad-battery-threshold-extension/-/issues'
            },
            {
                name: 'open-readme',
                link: 'https://gitlab.com/marcosdalvarez/thinkpad-battery-threshold-extension/'
            },
            {
                name: 'open-license',
                link: 'https://gitlab.com/marcosdalvarez/thinkpad-battery-threshold-extension/-/blob/main/LICENSE'
            },
        ];

        actions.forEach(action => {
            let act = new Gio.SimpleAction({ name: action.name });
            act.connect(
                'activate',
                _ => Gtk.show_uri(window, action.link, Gdk.CURRENT_TIME)
            );
            actionGroup.add_action(act);
        });
    }
});