'use strict';

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

const { General } = Me.imports.preferences.general;
const { Thinkpad } = Me.imports.preferences.thinkpad;
const { Experimental } = Me.imports.preferences.experimental;
const { About } = Me.imports.preferences.about;

const Driver = Me.imports.libs.driver;


/**
 * prefs initiation
 *
 * @returns {void}
 */
function init() {
    ExtensionUtils.initTranslations(Me.metadata.uuid);
}

/**
 * fill prefs window
 *
 * @returns {void}
 */
function fillPreferencesWindow(window) {

    const settings = ExtensionUtils.getSettings();
    const driver = new Driver.ThinkPad({'settings': settings});

    window.add(new General(settings));
    if (driver.isSupported) {
        window.add(new Thinkpad(settings, driver));
    }
    window.add(new Experimental(settings, driver));
    window.add(new About(window));

    window.search_enabled = true;
}